@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2006,
- *	2007, 2008, 2010 Tama Communications Corporation
+ *	2007, 2008, 2010, 2011 Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -63,6 +63,7 @@ void encode(char *, int, const char *);
 const char *localprefix;		/* local prefix		*/
 int aflag;				/* [option]		*/
 int cflag;				/* command		*/
+int dflag;				/* command		*/
 int fflag;				/* command		*/
 int gflag;				/* command		*/
 int Gflag;				/* [option]		*/
@@ -124,6 +125,7 @@ help(void)
 static struct option const long_options[] = {
 	{"absolute", no_argument, NULL, 'a'},
 	{"completion", no_argument, NULL, 'c'},
+	{"definition", no_argument, NULL, 'd'},
 	{"regexp", required_argument, NULL, 'e'},
 	{"file", no_argument, NULL, 'f'},
 	{"local", no_argument, NULL, 'l'},
@@ -196,7 +198,7 @@ decide_tag_by_context(const char *tag, const char *file, int lineno)
 	int iscompline = 0;
 
 	if (normalize(file, get_root_with_slash(), cwd, path, sizeof(path)) == NULL)
-		die("'%s' is out of source tree.", file);
+		die("'%s' is out of the source project.", file);
 	/*
 	 * get file id
 	 */
@@ -308,7 +310,8 @@ main(int argc, char **argv)
 	int optchar;
 	int option_index = 0;
 
-	while ((optchar = getopt_long(argc, argv, "ace:ifgGIlL:noOpPqrstTuvVx", long_options, &option_index)) != EOF) {
+	logging_arguments(argc, argv);
+	while ((optchar = getopt_long(argc, argv, "acde:ifgGIlL:noOpPqrstTuvVx", long_options, &option_index)) != EOF) {
 		switch (optchar) {
 		case 0:
 			break;
@@ -319,6 +322,10 @@ main(int argc, char **argv)
 			cflag++;
 			setcom(optchar);
 			break;
+		case 'd':
+			dflag++;
+			setcom(optchar);
+			break;
 		case 'e':
 			av = optarg;
 			break;
@@ -590,7 +597,9 @@ main(int argc, char **argv)
 			die_with_code(2, "regular expression is not allowed with the --from-here option.");
 		db = decide_tag_by_context(av, context_file, atoi(context_lineno));
 	} else {
-		if (rflag && sflag)
+		if (dflag)
+			db = GTAGS;
+		else if (rflag && sflag)
 			db = GRTAGS + GSYMS;
 		else
 			db = (rflag) ? GRTAGS : ((sflag) ? GSYMS : GTAGS);
@@ -975,7 +984,7 @@ grep(const char *pattern, char *const *argv, const char *dbpath)
 
 			if (normalize(path, get_root_with_slash(), cwd, buf, sizeof(buf)) == NULL)
 				if (!qflag)
-					fprintf(stderr, "'%s' is out of source tree.\n", path);
+					fprintf(stderr, "'%s' is out of the source project.\n", path);
 			if (!test("f", buf))
 				die("'%s' not found. Please remake tag files by invoking gtags(1).", path);
 			path = buf;
@@ -1166,7 +1175,6 @@ void
 parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpath, int db)
 {
 	int count = 0;
-	int file_count = 0;
 	STRBUF *sb = strbuf_open(0);
 	char *langmap;
 	const char *plugin_parser, *av;
@@ -1214,40 +1222,41 @@ parsefile(char *const *argv, const char *cwd, const char *root, const char *dbpa
 		/*
 		 * convert the path into relative to the root directory of source tree.
 		 */
-		if (normalize(av, get_root_with_slash(), cwd, path, sizeof(path)) == NULL)
+		if (normalize(av, get_root_with_slash(), cwd, path, sizeof(path)) == NULL) {
 			if (!qflag)
-				fprintf(stderr, "'%s' is out of source tree.\n", path + 2);
+				die("'%s' is out of the source project.", av);
+			continue;
+		}
+		if (!test("f", makepath(root, path, NULL))) {
+			if (!qflag) {
+				if (test("d", NULL))
+					die("'%s' is not a source file.", av);
+				else
+					die("'%s' not found.", av);
+			}
+			continue;
+		}
 		/*
 		 * Memorize the file id of the path. This is used in put_syms().
 		 */
 		{
 			static char s_fid[MAXFIDLEN];
-			const char *p = gpath_path2fid(path, NULL);
+			int type = 0;
+			const char *p = gpath_path2fid(path, &type);
 
-			if (!p) {
+			if (!p || type != GPATH_SOURCE) {
 				if (!qflag)
-					fprintf(stderr, "'%s' not found in GPATH.\n", path + 2);
+					die("'%s' is not a source file.", av);
 				continue;
 			}
 			strlimcpy(s_fid, p, sizeof(s_fid));
 			data.fid = s_fid;
 		}
-		if (!test("f", makepath(root, path, NULL))) {
-			if (test("d", NULL)) {
-				if (!qflag)
-					fprintf(stderr, "'%s' is a directory.\n", av);
-			} else {
-				if (!qflag)
-					fprintf(stderr, "'%s' not found.\n", av);
-			}
-			continue;
-		}
 		if (lflag && !locatestring(path, localprefix, MATCH_AT_FIRST))
 			continue;
 		data.count = 0;
 		parse_file(path, 0, put_syms, &data);
 		count += data.count;
-		file_count++;
 	}
 	args_close();
 	parser_exit();
