@@ -98,6 +98,15 @@ extern const char *empty_element;
 extern const char *noframes_begin;
 extern const char *noframes_end;
 
+extern const char *tree_control;
+extern const char *tree_begin;
+extern const char *tree_begin_using;
+extern const char *tree_end;
+extern const char *dir_begin;
+extern const char *dir_end;
+extern const char *file_begin;
+extern const char *file_end;
+
 int fputs_nl(const char *, FILE *);
 void setup_xhtml(void);
 void save_current_path(const char *);
@@ -107,6 +116,7 @@ const char *upperdir(const char *);
 const char *gen_insert_header(int);
 const char *gen_insert_footer(int);
 const char *gen_page_begin(const char *, int);
+const char *gen_page_index_begin(const char *, const char *);
 const char *gen_page_frameset_begin(const char *);
 const char *gen_page_end(void);
 const char *gen_image(int, const char *, const char *);
